@@ -1,11 +1,12 @@
+use 5.008;
 use strict;
 use warnings;
 package Task::BenchmarkAnything;
-BEGIN {
-  $Task::BenchmarkAnything::AUTHORITY = 'cpan:SCHWIGON';
-}
+# git description: v0.002-2-gc214c60
+
+our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: Max dependencies for BenchmarkAnything
-$Task::BenchmarkAnything::VERSION = '0.002';
+$Task::BenchmarkAnything::VERSION = '0.003';
 
 __END__
 
@@ -19,7 +20,7 @@ Task::BenchmarkAnything - Max dependencies for BenchmarkAnything
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 TASK CONTENTS
 
@@ -41,6 +42,10 @@ version 0.002
 
 =head3 L<DBD::SQLite>
 
+=head2 application support
+
+=head3 L<IO::Socket::SSL>
+
 1;
 
 =head1 AUTHOR
@@ -49,7 +54,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Steffen Schwigon.
+This software is copyright (c) 2016 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
